@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 use strict;
 use warnings;
@@ -6,6 +6,7 @@ no warnings 'redefine';
 
 use lib qw(. t lib .. ../t ../lib);
 use RDF::Query;
+use RDF::Query::Util;
 
 unless (@ARGV) {
 	print <<"END";
@@ -17,9 +18,6 @@ END
 	exit;
 }
 
-my $qfile	= shift;
-my $sparql	= do { open(my $fh, '<', $qfile) or die $!; local($/) = undef; <$fh> };
-
 use GraphViz;
 use List::Util qw(first);
 use Time::HiRes qw(tv_interval gettimeofday);
@@ -48,6 +46,8 @@ foreach my $i (0 .. $#triples) {
 	foreach my $n (@nodes) {
 		if ($n->isa('RDF::Query::Node::Variable')) {
 			push( @{ $vars{ $n->name } }, $i );
+		} elsif ($n->isa('RDF::Query::Node::Blank')) {
+			push( @{ $vars{ '_:' . $n->blank_identifier } }, $i );
 		}
 	}
 }
